==> haskell-hls-fourmolu-plugin-2.0.0.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.0.0.0-BqzSnyp59pnA1PvGHPWpZJ
key:                  hls-fourmolu-plugin-2.0.0.0-BqzSnyp59pnA1PvGHPWpZJ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c3e8e4fb1ee8c689c3f5d9521b44dddc
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.0.0.0-BqzSnyp59pnA1PvGHPWpZJ
depends:
    base-4.17.2.1 filepath-1.4.2.2
    fourmolu-0.10.1.0-InwvaMWbHu95MMIfNYd628 ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.0.0.0-4609leSVNx8jEc5FHwoPb
    hls-plugin-api-2.0.0.0-IkUAKif7SOT5m5YvwV0vz7
    lens-5.2.3-7QGQofAPyKYFc2G6dgdqBs
    lsp-1.6.0.0-Jj5cZac2KShEtujPemnlw4
    process-extras-0.7.4-L3Vye8ARLThHhjFp8Fu7RC text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-fourmolu-plugin-2.0.0.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.0.0.0-H3PJVcqot83GWXGjPAwgGw
key:                  hls-fourmolu-plugin-2.0.0.0-H3PJVcqot83GWXGjPAwgGw
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3d1e85199fe9b7ad1ee64ada75c2e8af
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.0.0.0-H3PJVcqot83GWXGjPAwgGw
depends:
    base-4.17.2.1 filepath-1.4.2.2
    fourmolu-0.10.1.0-KW7SeKmMWaQEr8TW2TeXjJ ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.0.0.0-H1ICRTE2M66EqglwlJk8PL
    hls-plugin-api-2.0.0.0-GY4wpL8VIcU79R7yyVXxr
    lens-5.2.3-7QGQofAPyKYFc2G6dgdqBs
    lsp-1.6.0.0-Jj5cZac2KShEtujPemnlw4
    process-extras-0.7.4-L3Vye8ARLThHhjFp8Fu7RC text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
